@@ -24,6 +24,7 @@ source $TOP_DIR/lib/neutron_plugins/ovs_base
 # Import ODL settings
 source $NETWORKING_ODL_DIR/devstack/settings.odl
 source $NETWORKING_ODL_DIR/devstack/odl-releases/$ODL_RELEASE
+source $NETWORKING_ODL_DIR/devstack/odl-releases/common
 
 # Utilities functions for setting up Java
 source $NETWORKING_ODL_DIR/devstack/setup_java.sh
@@ -57,7 +58,7 @@ if is_service_enabled odl-server; then
         :
     fi
 
-    if [[ "$1" == "unstack" ]]; then
+    if [[ "$1" == "unstack" && "$UNSTACK_KEEP_ODL" != "True" ]]; then
         stop_opendaylight
         cleanup_opendaylight
     fi
@@ -70,6 +71,7 @@ fi
 
 if is_service_enabled odl-compute; then
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
+        install_networking_odl
         install_opendaylight_compute
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         if is_service_enabled nova; then
@@ -77,7 +79,10 @@ if is_service_enabled odl-compute; then
         fi
         bind_opendaylight_controller
         wait_for_active_bridge $OVS_BR $ODL_RETRY_SLEEP_INTERVAL $ODL_BOOT_WAIT
-        if [ "${ODL_L3}" == "True" ]; then
+
+        # L3 needs to be configured only for netvirt-ovsdb - in netvirt-vpnservice L3 is configured
+        # by provider_mappings, and the provider mappings are added to br-int by default
+        if [[ ",$ODL_NETVIRT_KARAF_FEATURE," =~ ",$ODL_NETVIRT_KARAF_FEATURE_OVSDB," ]] && [ "${ODL_L3}" == "True" ]; then
             configure_opendaylight_l3
         fi
     elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
@@ -88,7 +93,7 @@ if is_service_enabled odl-compute; then
         :
     fi
 
-    if [[ "$1" == "unstack" ]]; then
+    if [[ "$1" == "unstack" && "$UNSTACK_KEEP_ODL" != "True" ]]; then
         cleanup_opendaylight_compute
     fi
 
@@ -100,7 +105,7 @@ fi
 
 if is_service_enabled odl-neutron; then
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
-        install_opendaylight_neutron_thin_ml2_driver
+        install_networking_odl
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         configure_neutron_odl
     elif [[ "$1" == "stack" && "$2" == "post-extra" ]]; then
@@ -121,7 +126,7 @@ fi
 
 if is_service_enabled odl-lightweight-testing; then
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
-        install_opendaylight_neutron_thin_ml2_driver
+        install_networking_odl
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         configure_neutron_odl
         configure_neutron_odl_lightweight_testing
